%bcond_without activation
%bcond_without cglib
%bcond_without dom4j
%bcond_without jdom
%bcond_without jdom2
%bcond_with jettison
%bcond_with joda-time
%bcond_with kxml2
%bcond_with stax
%bcond_with woodstox
%bcond_with xom
%bcond_with xpp3

Name:           xstream
Version:        1.4.20
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java XML serialization library
License:        BSD
URL:            https://x-stream.github.io
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch
Source0:        https://repo1.maven.org/maven2/com/thoughtworks/%{name}/%{name}-distribution/%{version}/%{name}-distribution-%{version}-src.zip
BuildRequires:  maven-local
BuildRequires:  mvn(io.github.x-stream:mxparser)
BuildRequires:  mvn(jakarta.xml.bind:jakarta.xml.bind-api:2)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
%if %{with activation}
BuildRequires:  mvn(jakarta.activation:jakarta.activation-api:1)
%endif
%if %{with cglib}
BuildRequires:  mvn(cglib:cglib-nodep)
%endif
%if %{with dom4j}
BuildRequires:  mvn(dom4j:dom4j)
%endif
%if %{with jdom}
BuildRequires:  mvn(org.jdom:jdom)
%endif
%if %{with jdom2}
BuildRequires:  mvn(org.jdom:jdom2)
%endif
%if %{with jettison}
BuildRequires:  mvn(org.codehaus.jettison:jettison)
%endif
%if %{with joda-time}
BuildRequires:  mvn(joda-time:joda-time)
%endif
%if %{with kxml2}
BuildRequires:  mvn(net.sf.kxml:kxml2-min)
%endif
%if %{with stax}
BuildRequires:  mvn(stax:stax)
BuildRequires:  mvn(stax:stax-api)
%endif
%if %{with woodstox}
BuildRequires:  mvn(org.codehaus.woodstox:wstx-asl)
%endif
%if %{with xom}
BuildRequires:  mvn(xom:xom)
%endif
%if %{with xpp3}
BuildRequires:  mvn(xpp3:xpp3_min)
%endif

%description
XStream is a simple library to serialize objects to XML
and back again. A high level facade is supplied that
simplifies common use cases. Custom objects can be serialized
without need for specifying mappings. Speed and low memory
footprint are a crucial part of the design, making it suitable
for large object graphs or systems with high message throughput.
No information is duplicated that can be obtained via reflection.
This results in XML that is easier to read for humans and more
compact than native Java serialization. XStream serializes internal
fields, including private and final. Supports non-public and inner
classes. Classes are not required to have default constructor.
Duplicate references encountered in the object-model will be
maintained. Supports circular references. By implementing an
interface, XStream can serialize directly to/from any tree
structure (not just XML). Strategies can be registered allowing
customization of how particular types are represented as XML.
When an exception occurs due to malformed XML, detailed diagnostics
are provided to help isolate and fix the problem.

%package -n %{name}-benchmark
Summary:        Benchmark module for %{name}
%description -n %{name}-benchmark
Benchmark module for %{name}.

%{?javadoc_package}

%prep
# -n: base directory name
%autosetup -n %{name}-%{version}
# delete precompiled jar and class files
find -type f '(' -iname '*.jar' -o -iname '*.class' ')' -print -delete
# change javax to jakarta
# https://jakarta.ee/about/faq#What_happened_with_javax.*_namespace?
%pom_change_dep -r javax.activation:activation jakarta.activation:jakarta.activation-api:1
%pom_change_dep -r javax.xml.bind:jaxb-api jakarta.xml.bind:jakarta.xml.bind-api:2
# remove dependency plugin
%pom_remove_plugin -r :maven-dependency-plugin
# optional dep: activation
%if %{without activation}
%pom_remove_dep -r jakarta.activation:jakarta.activation-api
rm xstream/src/java/com/thoughtworks/xstream/converters/extended/ActivationDataFlavorConverter.java
%endif
# optional dep: cglib
%if %{without cglib}
%pom_remove_dep -r cglib:cglib-nodep
rm xstream/src/java/com/thoughtworks/xstream/converters/reflection/CGLIBEnhancedConverter.java
rm xstream/src/java/com/thoughtworks/xstream/mapper/CGLIBMapper.java
rm xstream/src/java/com/thoughtworks/xstream/security/CGLIBProxyTypePermission.java
%endif
# optional dep: dom4j
%if %{without dom4j}
%pom_remove_dep -r dom4j:dom4j
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Dom4JDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Dom4JReader.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Dom4JWriter.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Dom4JXmlWriter.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamDom4J.java
%endif
# optional dep: jdom
%if %{without jdom}
%pom_remove_dep -r org.jdom:jdom
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDomDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDomReader.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDomWriter.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamJDom.java
%endif
# optional dep: jdom2
%if %{without jdom2}
%pom_remove_dep -r org.jdom:jdom2
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDom2Driver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDom2Reader.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/JDom2Writer.java
%endif
# optional dep: jettison
%if %{without jettison}
%pom_remove_dep -r org.codehaus.jettison:jettison
rm xstream/src/java/com/thoughtworks/xstream/io/json/JettisonMappedXmlDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/json/JettisonStaxWriter.java
%endif
# optional dep: joda-time
%if %{without joda-time}
%pom_remove_dep -r joda-time:joda-time
rm xstream/src/java/com/thoughtworks/xstream/core/util/ISO8601JodaTimeConverter.java
%endif
# optional dep: kxml2
%if %{without kxml2}
%pom_remove_dep -r net.sf.kxml:kxml2-min
rm xstream/src/java/com/thoughtworks/xstream/io/xml/KXml2DomDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/KXml2Driver.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamKXml2.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamKXml2DOM.java
%endif
# optional dep: stax
%if %{without stax}
%pom_remove_dep -r stax:stax
%pom_remove_dep -r stax:stax-api
rm xstream/src/java/com/thoughtworks/xstream/io/xml/BEAStaxDriver.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamBEAStax.java
%endif
# optional dep: woodstox
%if %{without woodstox}
%pom_remove_dep -r org.codehaus.woodstox:wstx-asl
%pom_remove_dep -r com.fasterxml.woodstox:woodstox-core
rm xstream/src/java/com/thoughtworks/xstream/io/xml/WstxDriver.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamWoodstox.java
%endif
# optional dep: xom
%if %{without xom}
%pom_remove_dep -r xom:xom
rm xstream/src/java/com/thoughtworks/xstream/io/xml/XomDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/XomReader.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/XomWriter.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamXom.java
%endif
# optional dep: xpp3
%if %{without xpp3}
%pom_remove_dep -r xpp3:xpp3_min
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Xpp3DomDriver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/Xpp3Driver.java
rm xstream/src/java/com/thoughtworks/xstream/io/xml/xppdom/Xpp3DomBuilder.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamXpp3.java
rm xstream-benchmark/src/java/com/thoughtworks/xstream/tools/benchmark/products/XStreamXpp3DOM.java
%endif
# disable module distribution
%pom_disable_module %{name}-distribution
# disable module hibernate
%pom_disable_module %{name}-hibernate
# disable module jmh
%pom_disable_module %{name}-jmh
# don't install parent package
%mvn_package :%{name}-parent __noinstall

%build
%mvn_build -s -f -- -Dversion.java.source=1.8 -Dversion.java.target=1.8

%install
%mvn_install

%files -n %{name} -f .mfiles-%{name}
%license LICENSE.txt
%doc README.txt
%files -n %{name}-benchmark -f .mfiles-%{name}-benchmark
%license LICENSE.txt
%doc README.txt


%changelog
* Thu Sep 14 2023 daviddavid <daviddavid> 1.4.20-2.mga10
+ Revision: 1986658
- Depend on compat versions of activation and XML bind (by @mkoncek)
- Re-enable activation

* Tue Mar 14 2023 daviddavid <daviddavid> 1.4.20-1.mga9
+ Revision: 1948936
- new version: 1.4.20, fixes CVE-2021-43859 and CVE-2022-41966 (mga#30044)

* Tue Jul 26 2022 neoclust <neoclust> 1.4.19-1.mga9
+ Revision: 1871884
- New version 1.4.19
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Oct 09 2021 neoclust <neoclust> 1.4.18-1.mga9
+ Revision: 1750208
- New version 1.4.18

* Fri Jul 23 2021 neoclust <neoclust> 1.4.15-2.mga9
+ Revision: 1737509
- Add P100/101: Fixes CVE-2021-2134[1-9], CVE-2021-2135[01], CVE-2021-29505 (mga#28844)
- New version 1.4.16 (mga#28844)

* Wed Dec 30 2020 neoclust <neoclust> 1.4.15-1.mga8
+ Revision: 1665761
- New version 1.4.15 (mga#27980)

* Thu Dec 24 2020 neoclust <neoclust> 1.4.14-1.mga8
+ Revision: 1663404
- New version 1.4.14  (mga#CVE-2020-26217)

* Fri Sep 04 2020 daviddavid <daviddavid> 1.4.12-1.mga8
+ Revision: 1621603
- Update to version 1.4.12
- Disable optional support for BEA Stax by default
- Disable optional support for joda-time by default
- Disable unused optional dom4j, jdom, jdom2, kxml, and woodstox support
- Rebuilt for JDK-11
- Allow building on JDK11

* Sat Feb 15 2020 umeabot <umeabot> 1.4.11.1-3.mga8
+ Revision: 1527915
- Mageia 8 Mass Rebuild

* Sat Jul 27 2019 daviddavid <daviddavid> 1.4.11.1-2.mga8
+ Revision: 1424541
- Disable hibernate support by default

* Thu Jul 18 2019 daviddavid <daviddavid> 1.4.11.1-1.mga8
+ Revision: 1422378
- Update to latest upstream release 1.4.11.1
- Allow building with reduced dependency set

* Wed Sep 19 2018 umeabot <umeabot> 1.4.9-4.mga7
+ Revision: 1277357
- Mageia 7 Mass Rebuild

* Tue May 16 2017 neoclust <neoclust> 1.4.9-3.mga6
+ Revision: 1101858
- Add P1 - Fixes CVE-2017-7957 (mga#20782)

* Sat Apr 22 2017 neoclust <neoclust> 1.4.9-2.mga6
+ Revision: 1097080
- Add P0: Fixes mga#20704

* Wed Apr 27 2016 daviddavid <daviddavid> 1.4.9-1.mga6
+ Revision: 1006970
- Update to 1.4.9
- Resolves: CVE-2016-3674 (mga#18277)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.4.8-3.mga6
+ Revision: 978243
- First rebuild of the java stack
- sync package xstream with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 daviddavid <daviddavid> 1.4.8-1.mga6
+ Revision: 844597
- sync with fc23 (update to 1.4.8)
- fix owner of maven-poms dir

* Sun Jan 11 2015 pterjan <pterjan> 1.4.7-5.mga5
+ Revision: 809904
- Update BuildRequires
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 1.4.7-3.mga5
+ Revision: 742315
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon Feb 24 2014 luigiwalser <luigiwalser> 1.4.7-1.mga5
+ Revision: 596677
- sync with fedora to fix CVE-2013-7285:
  - 1.4.7
  - Spec file cleanup
  - Fix BR
  - Build with kxml2 and json

* Mon Dec 16 2013 dmorgan <dmorgan> 1.4.5-1.mga4
+ Revision: 557160
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.3.1-6.mga3
+ Revision: 387413
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 1.3.1-5.mga3
+ Revision: 325692
- Java Stack Mass Rebuild

* Thu Apr 28 2011 dmorgan <dmorgan> 1.3.1-4.mga1
+ Revision: 93160
- Rebuild after bootstrapping

* Wed Apr 27 2011 dmorgan <dmorgan> 1.3.1-3.mga1
+ Revision: 91907
- Rebuild after bootstrapping
- imported package xstream


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jun 14 2010 Alexander Kurtakov <akurtako@redhat.com> 1.3.1-1
- Update to 1.3.1.
- Install maven pom and depmap.

* Wed Dec 02 2009 Lubomir Rintel <lkundrak@v3.sk> - 1.2.2-4
- Cosmetic fixes

* Fri Nov 27 2009 Lubomir Rintel <lkundrak@v3.sk> - 0:1.2.2-3
- Drop gcj (suggested by Jochen Schmitt), we seem to need OpenJDK anyway
- Fix -javadoc Require
- Drop epoch

* Sun Nov 01 2009 Lubomir Rintel <lkundrak@v3.sk> - 0:1.2.2-2
- Greatly simplify for Fedora
- Disable tests, we don't have all that's required to run them
- Remove maven build

* Fri Jul 20 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.2.2-1jpp
- Upgrade to 1.2.2
- Build with maven2 by default
- Add poms and depmap frags

* Tue May 23 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.1.3-1jpp
- Upgrade to 1.1.3
- Patched to work with bea

* Mon Sep 13 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.2-2jpp
- Drop saxpath requirement
- Require jaxen >= 0:1.1

* Mon Aug 30 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.2-1jpp
- Upgrade to 1.0.2
- Delete included binary jars
- Change -Dbuild.sysclasspath "from only" to "first" (DynamicProxyTest)
- Relax some versioned dependencies
- Build with ant-1.6.2

* Fri Aug 06 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.1-2jpp
- Upgrade to ant-1.6.X

* Tue Jun 01 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.0.1-1jpp
- Upgrade to 1.0.1

* Fri Feb 13 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.3-1jpp
- Upgrade to 0.3
- Add manual subpackage

* Mon Jan 19 2004 Ralph Apel <r.apel at r-apel.de> - 0:0.2-1jpp
- First JPackage release
